Index: trunk/ppImage/src/ppImageDetrendReadout.c
===================================================================
--- trunk/ppImage/src/ppImageDetrendReadout.c	(revision 20626)
+++ trunk/ppImage/src/ppImageDetrendReadout.c	(revision 21364)
@@ -59,7 +59,7 @@
 
     // Weight on the basis of pixel value needs to be done after the overscan has been subtracted
-    if (options->doWeightBuild) {
-        // create the target mask and weight images
-        pmReadoutGenerateWeight(input, true);
+    if (options->doVarianceBuild) {
+        // create the target mask and variance images
+        pmReadoutGenerateVariance(input, true);
     }
 
